@@ -16,9 +16,9 @@
 
 #define DEFAULT_ANCHOR_FORMAT "id%03d"
 
-const char hex_table[] = 
+const unsigned char hex_table[] = 
 "0123456789ABCDEF";
-static char b64_table[] =
+static unsigned char b64_table[] =
 "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
 /*
@@ -122,6 +122,8 @@ syck_new_emitter()
     e->best_width = 80;
     e->style = scalar_none;
     e->stage = doc_open;
+    e->depth = 0;
+    e->max_depth = 512;
     e->indent = 2;
     e->level = -1;
     e->anchors = NULL;
@@ -362,7 +364,6 @@ syck_emit( SyckEmitter *e, st_data_t n )
     SYMID oid;
     char *anchor_name = NULL;
     int indent = 0;
-    long x = 0;
     SyckLevel *parent;
     SyckLevel *lvl = syck_emitter_current_level( e );
     
@@ -404,7 +405,7 @@ syck_emit( SyckEmitter *e, st_data_t n )
             e->anchored = st_init_numtable();
         }
 
-        if ( ! st_lookup( e->anchored, (st_data_t)anchor_name, (st_data_t *)&x ) )
+        if ( ! st_lookup( e->anchored, (st_data_t)anchor_name, 0 ) )
         {
             char *an = S_ALLOC_N( char, strlen( anchor_name ) + 3 );
             sprintf( an, "&%s ", anchor_name );
@@ -418,8 +419,7 @@ syck_emit( SyckEmitter *e, st_data_t n )
             syck_emitter_write( e, an, strlen( anchor_name ) + 2 );
             free( an );
 
-            x = 1;
-            st_insert( e->anchored, (st_data_t)anchor_name, (st_data_t)x );
+            st_insert( e->anchored, (st_data_t)anchor_name, 0 );
             lvl->anctag = 1;
         }
         else
@@ -571,7 +571,7 @@ syck_scan_scalar( int req_width, char *cursor, long len )
     }
     if ( ( cursor[0] == '-' || cursor[0] == ':' ||
            cursor[0] == '?' || cursor[0] == ',' ) &&
-           ( cursor[1] == ' ' || cursor[1] == '\n' || len == 1 ) )
+           ( cursor[1] == ' ' || cursor[1] == '\n' || cursor[1] == '\r' || len == 1 ) )
     {
             flags |= SCAN_INDIC_S;
     }
@@ -596,12 +596,12 @@ syck_scan_scalar( int req_width, char *cursor, long len )
     /* scan string */
     for ( i = 0; i < len; i++ ) {
 
-        if ( ! ( (unsigned)cursor[i] == 0x9 ||
-                 (unsigned)cursor[i] == 0xA ||
-                 (unsigned)cursor[i] == 0xD ||
-               ( (unsigned)cursor[i] >= 0x20 && (unsigned)cursor[i] <= 0x7E ) ||
-                 (unsigned)cursor[i] == 0x85 ||
-                 (unsigned)cursor[i] >= 0xa0 )
+        if ( ! ( (unsigned char)cursor[i] == 0x9 ||
+                 (unsigned char)cursor[i] == 0xA ||
+                 (unsigned char)cursor[i] == 0xD ||
+               ( (unsigned char)cursor[i] >= 0x20 &&
+                 (unsigned char)cursor[i] <= 0x7E ) ||
+                 (unsigned char)cursor[i] >= 0x80 )
         ) {
             flags |= SCAN_NONPRINT;
         }
@@ -810,7 +810,7 @@ void syck_emit_scalar( SyckEmitter *e, char *tag, enum scalar_style force_style,
 }
 
 void
-syck_emitter_escape( SyckEmitter *e, char *src, long len )
+syck_emitter_escape( SyckEmitter *e, unsigned char *src, long len )
 {
     int i;
     for( i = 0; i < len; i++ )
@@ -925,7 +925,7 @@ void syck_emit_2quoted_1( SyckEmitter *e, int width, char *str, long len )
             break;
 
             default:
-                syck_emitter_escape( e, mark, 1 );
+                syck_emitter_escape( e, (unsigned char *)mark, 1 );
             break;
         }
         mark++;
@@ -988,7 +988,7 @@ void syck_emit_2quoted( SyckEmitter *e, int width, char *str, long len )
             break;
 
             default:
-                syck_emitter_escape( e, mark, 1 );
+                syck_emitter_escape( e, (unsigned char*)mark, 1 );
             break;
         }
         mark++;
@@ -1296,7 +1296,7 @@ void syck_emit_end( SyckEmitter *e )
  * soon-to-be-emitted tree.
  */
 SYMID
-syck_emitter_mark_node( SyckEmitter *e, st_data_t n )
+syck_emitter_mark_node( SyckEmitter *e, st_data_t n, int flags )
 {
     SYMID oid = 0;
     char *anchor_name = NULL;
@@ -1348,8 +1348,11 @@ syck_emitter_mark_node( SyckEmitter *e, st_data_t n )
             st_insert( e->anchors, (st_data_t)oid, (st_data_t)anchor_name );
         }
 
+        /* XXX - Flag added by BDRACO as the perl_syck.h now has a max_depth - XXX */
+        if (! (flags & EMITTER_MARK_NODE_FLAG_PERMIT_DUPLICATE_NODES) ) {
+            return 0;
+        }
         /* XXX - Added by Audrey Tang to handle self-recursive structures - XXX */
-        return 0;
     }
     return oid;
 }
