@@ -32,10 +32,14 @@
 */
 
 struct emitter_xtra {
-    SV* port;
+    union {
+      SV* outsv;
+      PerlIO* outio;
+    } out;
     char* tag;
     char dump_code;
     bool implicit_binary;
+    int ioerror;
 };
 
 struct parser_xtra {
@@ -56,6 +60,7 @@ SV* perl_syck_lookup_sym( SyckParser *p, SYMID v) {
 #ifdef SvUTF8_on
 #define CHECK_UTF8 \
     if (((struct parser_xtra *)p->bonus)->implicit_unicode \
+      && n->data.str->len \
       && is_utf8_string((U8*)n->data.str->ptr, n->data.str->len)) \
         SvUTF8_on(sv);
 #else
@@ -72,15 +77,31 @@ SyckNode * perl_syck_bad_anchor_handler(SyckParser *p, char *a) {
 }
 
 void perl_syck_error_handler(SyckParser *p, char *msg) {
-    croak(form( "%s parser (line %d, column %ld): %s",
+    croak("%s parser (line %d, column %ld): %s",
         "Syck",
         p->linect + 1,
-        p->cursor - p->lineptr,
-        msg ));
+        (long) (p->cursor - p->lineptr),
+        msg );
 }
 
-void perl_syck_output_handler(SyckEmitter *e, char *str, long len) {
+void perl_syck_output_handler_pv(SyckEmitter *e, char *str, long len) {
     struct emitter_xtra *bonus = (struct emitter_xtra *)e->bonus;
-    sv_catpvn_nomg(bonus->port, str, len);
+    sv_catpvn_nomg(bonus->out.outsv, str, len);
+}
+
+void perl_syck_output_handler_mg(SyckEmitter *e, char *str, long len) {
+    struct emitter_xtra *bonus = (struct emitter_xtra *)e->bonus;
+    sv_catpvn_mg(bonus->out.outsv, str, len);
+}
+
+void perl_syck_output_handler_io(SyckEmitter *e, char *str, long len) {
+    struct emitter_xtra *bonus = (struct emitter_xtra *)e->bonus;
+    if (bonus->ioerror) {
+        return;
+    } else {
+        int wrote = PerlIO_write(bonus->out.outio, str, len);
+        if (wrote != len)
+          bonus->ioerror = (errno ? errno : -1);
+    }
 }
 
