@@ -2,7 +2,7 @@
  * syck.c
  *
  * $Author: why $
- * $Date: 2005-01-01 10:06:25 +0800 (.., 01  1 2005) $
+ * $Date: 2005-01-01 10:06:25 +0800 (六, 01  1 2005) $
  *
  * Copyright (C) 2003 why the lucky stiff
  */
@@ -503,19 +503,20 @@ syck_default_error_handler( SyckParser *p, char *msg )
 }
 
 int syck_str_is_unquotable_integer(char* str, long len) {
-	int idx;
+    int idx;
 
-	if(!str) return 0; /* Don't parse null strings */
-	if(len < 1) return 0; /* empty strings can't be numbers */
-	if(len > 9) return 0; /* Ints larger than 9 digits (32bit) might not portable. Force a string. */
+    if(!str) return 0; /* Don't parse null strings */
+    if(len < 1) return 0; /* empty strings can't be numbers */
+    if(len > 9) return 0; /* Ints larger than 9 digits (32bit) might not portable. Force a string. */
 
-	if(str[0] == '-' && (len < 2 || str[1] > '9' || str[1] < '1')) return 0;
-	if(str[0] > '9' || str[0] < '1') return 0;
+    if(str[0] == '0' && len == 1) return 1; /* 0 is unquoted. */
+    if(str[0] == '-') {str++; len --;} /* supress the leading '-' sign if detected for testing purposes only. */
+    if(str[0]  == '0') return 0; /* Octals need to be quoted or you lose data converting them to an integer. This also accidentally blocks -0 which probably needs to be quoted. */
 
-	/* Look for illegal characters */
-	for ( idx = 1; idx < len; idx++ ) {
-		if(!isdigit(str[idx])) return 0;
-	}
+    /* Look for illegal characters */
+    for ( idx = 1; idx < len; idx++ ) {
+        if(!isdigit(str[idx])) return 0;
+    }
 
-	return 1;
+    return 1;
 }
